foundationdb::budget

Struct BudgetExceeded

pub struct BudgetExceeded {
    pub kind: BudgetKind,
    pub used: u64,
    pub limit: u64,
}
A ClientBudget limit was exceeded by the current transaction attempt.

used and limit are expressed in milliseconds for BudgetKind::Time, in bytes otherwise.

Fields

kind: BudgetKind

The limit that was exceeded.

used: u64

What the attempt used, milliseconds for BudgetKind::Time, bytes otherwise.

limit: u64

The configured limit, in the same unit as used.