pub struct BudgetExceeded {
pub kind: BudgetKind,
pub used: u64,
pub limit: u64,
}Expand description
A ClientBudget limit was exceeded by the current transaction attempt.
used and limit are expressed in milliseconds for BudgetKind::Time,
in bytes otherwise.
Fields
kind: BudgetKindThe limit that was exceeded.
used: u64What the attempt used, milliseconds for BudgetKind::Time, bytes
otherwise.
limit: u64The configured limit, in the same unit as used.